var NAVTREEINDEX5 =
{
"classviennacl_1_1matrix__base.html#a25b797fdf4d3c841cae4d047f9cfbaee":[6,0,0,63,36],
"classviennacl_1_1matrix__base.html#a28087e6cd79a3eb13df18b40092966d3":[6,0,0,63,56],
"classviennacl_1_1matrix__base.html#a2896fa7b137959c57bcb5966a2a37870":[6,0,0,63,25],
"classviennacl_1_1matrix__base.html#a2a789435ff884ce9f1ff9d65025ba3e7":[6,0,0,63,3],
"classviennacl_1_1matrix__base.html#a2b8c9fe73ee98c4a55ac0d116ee9df38":[6,0,0,63,5],
"classviennacl_1_1matrix__base.html#a2cdca5a19d0e0d46a0ace69f1724b714":[6,0,0,63,28],
"classviennacl_1_1matrix__base.html#a33997bfe92e860894b22f5bb518a1290":[6,0,0,63,7],
"classviennacl_1_1matrix__base.html#a38f0caaff139f738da4d629a19eb8133":[6,0,0,63,45],
"classviennacl_1_1matrix__base.html#a4082cd3586bc99deb68733257b30c51f":[6,0,0,63,15],
"classviennacl_1_1matrix__base.html#a4348766b3b9cb049f7acd6a795272dbe":[6,0,0,63,53],
"classviennacl_1_1matrix__base.html#a49f216cbcd3c8ac055bf10727df36bb5":[6,0,0,63,51],
"classviennacl_1_1matrix__base.html#a4d68a8dc9bdca6b231f5eaffab98b3ec":[6,0,0,63,14],
"classviennacl_1_1matrix__base.html#a5239f29ffd79c36d9554cb1b79ae8c09":[6,0,0,63,27],
"classviennacl_1_1matrix__base.html#a55f4fded82d61ad7d193cf3080bf6761":[6,0,0,63,33],
"classviennacl_1_1matrix__base.html#a64319ec4bd226ca34e262dacb2092ded":[6,0,0,63,8],
"classviennacl_1_1matrix__base.html#a64faacf51cfa7b520268fc625af928c7":[6,0,0,63,32],
"classviennacl_1_1matrix__base.html#a69ce70a1df8ae8f97dd022b43fc81abe":[6,0,0,63,9],
"classviennacl_1_1matrix__base.html#a72ccdf250016fdd4599dfae6994b084c":[6,0,0,63,22],
"classviennacl_1_1matrix__base.html#a73e4c43075e9b9cb229d4fc9edf0f53f":[6,0,0,63,41],
"classviennacl_1_1matrix__base.html#a74ba45afe7c6c22128463a7a9eece697":[6,0,0,63,49],
"classviennacl_1_1matrix__base.html#a7a6d23943b12cf193cfc8439f10c5239":[6,0,0,63,29],
"classviennacl_1_1matrix__base.html#a7b8e8b021a29d73f43af3f1f4c36ecbc":[6,0,0,63,40],
"classviennacl_1_1matrix__base.html#a7bf3650d61c65915491a27d1fe8e115b":[6,0,0,63,34],
"classviennacl_1_1matrix__base.html#a7cd6f5dc0261fa507d78679bacce8ff3":[6,0,0,63,12],
"classviennacl_1_1matrix__base.html#a7d81490156aa0b0f8d6e268a01b954c5":[6,0,0,63,6],
"classviennacl_1_1matrix__base.html#a7f1b176eaa22875c3dc04750498616a1":[6,0,0,63,17],
"classviennacl_1_1matrix__base.html#a82018b4e169973bdfb9d3be68ceb5be0":[6,0,0,63,18],
"classviennacl_1_1matrix__base.html#a871a2766915f1ac53f9b906a5a6ece99":[6,0,0,63,35],
"classviennacl_1_1matrix__base.html#a89b777f4dbd07ecc26f251192107539d":[6,0,0,63,58],
"classviennacl_1_1matrix__base.html#a8c97fd0f8ea585ae4c6c2c9bd723ae7d":[6,0,0,63,30],
"classviennacl_1_1matrix__base.html#a97a05d0d15287911969ee656268e957d":[6,0,0,63,0],
"classviennacl_1_1matrix__base.html#a9d4b62d3c58f685b0625131ce08a85ab":[6,0,0,63,16],
"classviennacl_1_1matrix__base.html#a9e3d2257ed3bd0a67a0844aead9f9560":[6,0,0,63,43],
"classviennacl_1_1matrix__base.html#a9f7c56940f0779f63ed30a85534b29e3":[6,0,0,63,44],
"classviennacl_1_1matrix__base.html#a9f852147d9189e221aa2233956e45512":[6,0,0,63,13],
"classviennacl_1_1matrix__base.html#aa867b9e7459398ad43bf6d5db4099589":[6,0,0,63,1],
"classviennacl_1_1matrix__base.html#aa94289bd12b7cf72cde9671747aad467":[6,0,0,63,48],
"classviennacl_1_1matrix__base.html#ab4a24cdcf2bed1c6eb83532584cebaed":[6,0,0,63,26],
"classviennacl_1_1matrix__base.html#ac486bcceee85716926ddefa762d5425f":[6,0,0,63,2],
"classviennacl_1_1matrix__base.html#ac664dd7f9b647657b14d56ba2978ba59":[6,0,0,63,11],
"classviennacl_1_1matrix__base.html#ac7b6e3646eb0fd666bd503ca91971f8b":[6,0,0,63,38],
"classviennacl_1_1matrix__base.html#ace341780fc4c5533e2818ec3cafe26cb":[6,0,0,63,20],
"classviennacl_1_1matrix__base.html#ad4ca29d5901cf2249199db3be5ee0e72":[6,0,0,63,37],
"classviennacl_1_1matrix__base.html#ad5ff0f40c43720312c655b232436c14c":[6,0,0,63,39],
"classviennacl_1_1matrix__base.html#adc3585292c6d5bf3076dea46a9895289":[6,0,0,63,31],
"classviennacl_1_1matrix__base.html#ae0b8e1d66c44b4ebe8ec71516a36d572":[6,0,0,63,42],
"classviennacl_1_1matrix__base.html#ae7e59905da4da81d72faa4f1dabc92ea":[6,0,0,63,47],
"classviennacl_1_1matrix__base.html#aea8dcaba5a60e427b8712cefc1adb829":[6,0,0,63,46],
"classviennacl_1_1matrix__base.html#aeea51bfd213766338c847bf92117323c":[6,0,0,63,10],
"classviennacl_1_1matrix__base.html#af141f5216626734e44b8845981b54b0f":[6,0,0,63,55],
"classviennacl_1_1matrix__base.html#af73da8b36b54893fcb47beffab9312fa":[6,0,0,63,23],
"classviennacl_1_1matrix__base.html#aff9e2bae9a01d135bd089b1d3bacf6d1":[6,0,0,63,21],
"classviennacl_1_1matrix__expression.html":[6,0,0,64],
"classviennacl_1_1matrix__expression.html#a3125cc5f209063de6a99dc67e19d42bb":[6,0,0,64,4],
"classviennacl_1_1matrix__expression.html#a417180fdbc1a844aa9dc6b93fa9fbd9d":[6,0,0,64,0],
"classviennacl_1_1matrix__expression.html#a5e1aa68cd901d54ed3e4bc56882a5047":[6,0,0,64,3],
"classviennacl_1_1matrix__expression.html#a7bcf8a5fcdea84fba7fe989749791417":[6,0,0,64,1],
"classviennacl_1_1matrix__expression.html#aa2c582e8d2c1cafbf2ffdf05c9fdfaca":[6,0,0,64,2],
"classviennacl_1_1matrix__expression.html#ad8516f3a2ef4db4d5379fb64832fd39f":[6,0,0,64,5],
"classviennacl_1_1matrix__iterator.html":[6,0,0,65],
"classviennacl_1_1matrix__iterator.html#a15bda6557c012f86dc73d712bc71d7f3":[6,0,0,65,7],
"classviennacl_1_1matrix__iterator.html#a1837364083cd08f862d3ea5608af5f82":[6,0,0,65,2],
"classviennacl_1_1matrix__iterator.html#a3ff1ff49f79aea6ba824ecdb460ecc14":[6,0,0,65,1],
"classviennacl_1_1matrix__iterator.html#a839f7b14cdb91361b88dd6b230d6b505":[6,0,0,65,8],
"classviennacl_1_1matrix__iterator.html#a9b8eeaefaa8bf5276b8d63cf3a471ade":[6,0,0,65,4],
"classviennacl_1_1matrix__iterator.html#ab0dc7706eacde70d1857372b602b6bad":[6,0,0,65,3],
"classviennacl_1_1matrix__iterator.html#ab5b8c98222880e6ae5f92d54c7d06e14":[6,0,0,65,6],
"classviennacl_1_1matrix__iterator.html#ae11cd06a58c70e8a4f90fd5e1946a9ee":[6,0,0,65,0],
"classviennacl_1_1matrix__iterator.html#ae473cc7d80378c7384b365d4959457df":[6,0,0,65,5],
"classviennacl_1_1matrix__iterator.html#af1aee4972f71999a4f46dac773543530":[6,0,0,65,9],
"classviennacl_1_1matrix__range.html":[6,0,0,66],
"classviennacl_1_1matrix__range.html#a100b1ddda26bfd792b34b666c0dc23e2":[6,0,0,66,8],
"classviennacl_1_1matrix__range.html#a294649e885898124628094aa3acd5fa5":[6,0,0,66,4],
"classviennacl_1_1matrix__range.html#a3a6b55a656dc7ad97e7d2ad9aa625f18":[6,0,0,66,9],
"classviennacl_1_1matrix__range.html#a4064dc2a15d3ab796852dffb6cfd873b":[6,0,0,66,1],
"classviennacl_1_1matrix__range.html#a6178a1a8edf196ce5032738da4877b25":[6,0,0,66,7],
"classviennacl_1_1matrix__range.html#a6d841c457f8442372f9478d968f1fd1b":[6,0,0,66,2],
"classviennacl_1_1matrix__range.html#ad436ae3cbfcb2ab134f4b8727828259e":[6,0,0,66,6],
"classviennacl_1_1matrix__range.html#ae6dc2ea9e181e7305eb258397f2a75f1":[6,0,0,66,0],
"classviennacl_1_1matrix__range.html#aec19050aa8523003ebd04a0122c8bb2f":[6,0,0,66,5],
"classviennacl_1_1matrix__range.html#af11274e4ec8c01b269f6f928b34242c4":[6,0,0,66,3],
"classviennacl_1_1matrix__range_3_01matrix__range_3_01_matrix_type_01_4_01_4.html":[6,0,0,67],
"classviennacl_1_1matrix__range_3_01matrix__range_3_01_matrix_type_01_4_01_4.html#aa595c2260e61819b45437e38fe06169a":[6,0,0,67,2],
"classviennacl_1_1matrix__range_3_01matrix__range_3_01_matrix_type_01_4_01_4.html#ab399b835b9292482c71c2587834bfd7c":[6,0,0,67,1],
"classviennacl_1_1matrix__range_3_01matrix__range_3_01_matrix_type_01_4_01_4.html#ac046c47a64543a2e08fa700e2ca6b034":[6,0,0,67,0],
"classviennacl_1_1matrix__slice.html":[6,0,0,68],
"classviennacl_1_1matrix__slice.html#a30f8bdd48c7b3f3e470aab2a9d419bd7":[6,0,0,68,5],
"classviennacl_1_1matrix__slice.html#a383814f6e743f3e864dbe3b05dd8fa71":[6,0,0,68,3],
"classviennacl_1_1matrix__slice.html#a38cb8271a86001d19028cc2903546463":[6,0,0,68,1],
"classviennacl_1_1matrix__slice.html#a73ec32d37eb9c64e2e165abbb7e6d87b":[6,0,0,68,9],
"classviennacl_1_1matrix__slice.html#a75ffb6e46e07e6ffe2dbaef2d6bb7593":[6,0,0,68,7],
"classviennacl_1_1matrix__slice.html#a957bc283ab8327eb93ce863c9a734f32":[6,0,0,68,8],
"classviennacl_1_1matrix__slice.html#a9f10a6601fa6afe0d38a8f1e6483a90c":[6,0,0,68,4],
"classviennacl_1_1matrix__slice.html#aa899c7446878be8a9200e741e4d57fe3":[6,0,0,68,6],
"classviennacl_1_1matrix__slice.html#ad540bf380c5586b66d6ba3745555136f":[6,0,0,68,0],
"classviennacl_1_1matrix__slice.html#afe786a1f980fa21ff95d338784021598":[6,0,0,68,2],
"classviennacl_1_1matrix__slice_3_01matrix__range_3_01_matrix_type_01_4_01_4.html":[6,0,0,69],
"classviennacl_1_1matrix__slice_3_01matrix__range_3_01_matrix_type_01_4_01_4.html#a1405263a01e16f7bcd4c09fb8eb29bc7":[6,0,0,69,0],
"classviennacl_1_1matrix__slice_3_01matrix__range_3_01_matrix_type_01_4_01_4.html#aabe80bdcb1d57191aff173806d0b3e31":[6,0,0,69,1],
"classviennacl_1_1matrix__slice_3_01matrix__range_3_01_matrix_type_01_4_01_4.html#aef18c078f89c2851229dd91422fed2db":[6,0,0,69,2],
"classviennacl_1_1memory__exception.html":[6,0,0,70],
"classviennacl_1_1memory__exception.html#a0e8dfdd960da56daa8616f11780ffc3c":[6,0,0,70,2],
"classviennacl_1_1memory__exception.html#a2bd16efb8a50540d155c6eb81d5d45e4":[6,0,0,70,3],
"classviennacl_1_1memory__exception.html#a6ea59387f3ccdba0c559cb6a186ad7cc":[6,0,0,70,1],
"classviennacl_1_1memory__exception.html#abe5d81175f7dd39579b6337b90ea21ca":[6,0,0,70,0],
"classviennacl_1_1ocl_1_1backend.html":[6,0,0,5,1],
"classviennacl_1_1ocl_1_1build__program__failure.html":[6,0,0,5,2],
"classviennacl_1_1ocl_1_1command__queue.html":[6,0,0,5,3],
"classviennacl_1_1ocl_1_1command__queue.html#a31862d3455bd31b51ecdcdadebbbde79":[6,0,0,5,3,2],
"classviennacl_1_1ocl_1_1command__queue.html#a4516024c4cec5147e582ca85e0fe1f00":[6,0,0,5,3,4],
"classviennacl_1_1ocl_1_1command__queue.html#a670f2d080528e50d64d3912567708754":[6,0,0,5,3,5],
"classviennacl_1_1ocl_1_1command__queue.html#a932d287769eebe9ef045ab85b4575706":[6,0,0,5,3,7],
"classviennacl_1_1ocl_1_1command__queue.html#a93a510254baa209cbfcab51eda30e780":[6,0,0,5,3,1],
"classviennacl_1_1ocl_1_1command__queue.html#ab38b51dc74556adb044ea9f8e4c458e9":[6,0,0,5,3,6],
"classviennacl_1_1ocl_1_1command__queue.html#ae2e51d158444a51341af30cebc5cf88b":[6,0,0,5,3,3],
"classviennacl_1_1ocl_1_1command__queue.html#af9ace720a0aae631ac5eaf791c6c6160":[6,0,0,5,3,8],
"classviennacl_1_1ocl_1_1command__queue.html#afe48096ca16c17701bc016df6854ca80":[6,0,0,5,3,0],
"classviennacl_1_1ocl_1_1compiler__not__available.html":[6,0,0,5,4],
"classviennacl_1_1ocl_1_1context.html":[6,0,0,5,5],
"classviennacl_1_1ocl_1_1context.html#a0f1a9e025d6fcdd44b21d8f80fa8c446":[6,0,0,5,5,0],
"classviennacl_1_1ocl_1_1context.html#a122abd131e682733ff44bdf480365ba2":[6,0,0,5,5,23],
"classviennacl_1_1ocl_1_1context.html#a1b1339c711fd666c8bdc9104f47670d4":[6,0,0,5,5,25],
"classviennacl_1_1ocl_1_1context.html#a2579803294df7a517efc5551e02ca9ec":[6,0,0,5,5,7],
"classviennacl_1_1ocl_1_1context.html#a27347b71cec98f6636de39e91e767f4f":[6,0,0,5,5,21],
"classviennacl_1_1ocl_1_1context.html#a2af175f7e99efa33ad852ab3d871f666":[6,0,0,5,5,22],
"classviennacl_1_1ocl_1_1context.html#a3b505875590e899db5538daf05f74b05":[6,0,0,5,5,6],
"classviennacl_1_1ocl_1_1context.html#a43602c712b8c33cf6c9c5eeebdbe0eb7":[6,0,0,5,5,35],
"classviennacl_1_1ocl_1_1context.html#a4ad17f85bfc2e5715c9e327c40138d43":[6,0,0,5,5,42],
"classviennacl_1_1ocl_1_1context.html#a4f0b8c81dad769f6efffe2d2069101f8":[6,0,0,5,5,8],
"classviennacl_1_1ocl_1_1context.html#a4f89a62af0d767fd8a4f5f07323447ea":[6,0,0,5,5,38],
"classviennacl_1_1ocl_1_1context.html#a562e2d1a9a55e647570734c4f62a22e2":[6,0,0,5,5,9],
"classviennacl_1_1ocl_1_1context.html#a566dfbe8b8e1588ae21c50091682d1ce":[6,0,0,5,5,19],
"classviennacl_1_1ocl_1_1context.html#a611d95b11db04230f63e37bfeae911db":[6,0,0,5,5,32],
"classviennacl_1_1ocl_1_1context.html#a6aa5ef5cb563ed047ff72f286eb5718b":[6,0,0,5,5,10],
"classviennacl_1_1ocl_1_1context.html#a734307b352a0137c93f22cfebed89dfe":[6,0,0,5,5,2],
"classviennacl_1_1ocl_1_1context.html#a7ccf3c2f3be355f39ea07cfea9600369":[6,0,0,5,5,1],
"classviennacl_1_1ocl_1_1context.html#a7e593822095e5680fc8de44e34cb4131":[6,0,0,5,5,34],
"classviennacl_1_1ocl_1_1context.html#a83052a42aed14d8ff9d3df4773908f64":[6,0,0,5,5,27],
"classviennacl_1_1ocl_1_1context.html#a85373fa81be824eef324579bf429d201":[6,0,0,5,5,41],
"classviennacl_1_1ocl_1_1context.html#a8ac887230ee381a0f5f9df2a22129155":[6,0,0,5,5,37],
"classviennacl_1_1ocl_1_1context.html#a9094ac71f0cdf80df698c0c84ebb483d":[6,0,0,5,5,3],
"classviennacl_1_1ocl_1_1context.html#a93e86f0d0b9fbd725fcce5af704a45a0":[6,0,0,5,5,4],
"classviennacl_1_1ocl_1_1context.html#a9a4b85b384428c041f357fb53ce18bdb":[6,0,0,5,5,44],
"classviennacl_1_1ocl_1_1context.html#aa24993e6aa8c9d229fc76f03500dab79":[6,0,0,5,5,17],
"classviennacl_1_1ocl_1_1context.html#ab46ef3e70b91c8918f802bd301cf5462":[6,0,0,5,5,39],
"classviennacl_1_1ocl_1_1context.html#ab4d9064422cc8c183a14ad77c2a7b49b":[6,0,0,5,5,15],
"classviennacl_1_1ocl_1_1context.html#ab82ee61d71620fda1a52b2500b090b06":[6,0,0,5,5,13],
"classviennacl_1_1ocl_1_1context.html#ac168354a69dda2f884b35ae3baad989b":[6,0,0,5,5,26],
"classviennacl_1_1ocl_1_1context.html#ac1cbe98ad9b39507daf6d616fedd9faf":[6,0,0,5,5,11],
"classviennacl_1_1ocl_1_1context.html#ac51b862f074e4cacc05bf627c60898cd":[6,0,0,5,5,33],
"classviennacl_1_1ocl_1_1context.html#ac70d01bc7f8bd1f36c10eae811672d79":[6,0,0,5,5,12],
"classviennacl_1_1ocl_1_1context.html#ac8545f52ca32888b0100373f833d7e98":[6,0,0,5,5,40],
"classviennacl_1_1ocl_1_1context.html#acc93998e7854314823a339d60989256b":[6,0,0,5,5,18],
"classviennacl_1_1ocl_1_1context.html#ad14902e6145fc89fa77dc412c46eb58f":[6,0,0,5,5,14],
"classviennacl_1_1ocl_1_1context.html#ada9eb8e202ccdc281bd3a7400dc35806":[6,0,0,5,5,31],
"classviennacl_1_1ocl_1_1context.html#ae335105dfd69a228e80b7d223ffe3251":[6,0,0,5,5,20],
"classviennacl_1_1ocl_1_1context.html#ae77103e689b9a42771e7d66515c33995":[6,0,0,5,5,30],
"classviennacl_1_1ocl_1_1context.html#aea197161de5f5617b8a2208482b41ed9":[6,0,0,5,5,36],
"classviennacl_1_1ocl_1_1context.html#af4f7f70a51d069f7796bd9b4bb2a852a":[6,0,0,5,5,29],
"classviennacl_1_1ocl_1_1context.html#af6f574a9f1fb21a1ce68eeb567e04ca0":[6,0,0,5,5,16],
"classviennacl_1_1ocl_1_1context.html#afa14c1aacc2b9db5f14816d75fee0fc7":[6,0,0,5,5,5],
"classviennacl_1_1ocl_1_1context.html#afe385511ee81db67a2323caf177a7b58":[6,0,0,5,5,28],
"classviennacl_1_1ocl_1_1context.html#afe68ad8c2df449f40f45db6605038946":[6,0,0,5,5,24],
"classviennacl_1_1ocl_1_1context.html#aff857b8f638c200abfb06c35af0c45f3":[6,0,0,5,5,43],
"classviennacl_1_1ocl_1_1device.html":[6,0,0,5,8],
"classviennacl_1_1ocl_1_1device.html#a002ae911ec980a4da1df41d7fa4b688c":[6,0,0,5,8,53],
"classviennacl_1_1ocl_1_1device.html#a030b10500077e52fb85b20c75656784b":[6,0,0,5,8,5],
"classviennacl_1_1ocl_1_1device.html#a0b8bd02b47bff8d2a8169cc7d230b68f":[6,0,0,5,8,60],
"classviennacl_1_1ocl_1_1device.html#a0d513e15eb829b7a3401079c5a224071":[6,0,0,5,8,51],
"classviennacl_1_1ocl_1_1device.html#a11dced0599d69791413707ae49426fef":[6,0,0,5,8,11],
"classviennacl_1_1ocl_1_1device.html#a1248fe748267363cbc9c884f17f095f0":[6,0,0,5,8,55],
"classviennacl_1_1ocl_1_1device.html#a12c63e2f0937a8a025016042b211139f":[6,0,0,5,8,50],
"classviennacl_1_1ocl_1_1device.html#a17ae0516fdd84fd1eb762bba646d9ac9":[6,0,0,5,8,18],
"classviennacl_1_1ocl_1_1device.html#a18a16867d9b70941b9c708ca2ff63794":[6,0,0,5,8,21],
"classviennacl_1_1ocl_1_1device.html#a1c21bd14510294044e383bc44c406b87":[6,0,0,5,8,40],
"classviennacl_1_1ocl_1_1device.html#a1cb9939e106bed65173c29bfe3f0f198":[6,0,0,5,8,2],
"classviennacl_1_1ocl_1_1device.html#a1d7b317b5ba58f87d01afd5249fcf763":[6,0,0,5,8,48],
"classviennacl_1_1ocl_1_1device.html#a204d0038c694efb1b006bd768008da8f":[6,0,0,5,8,49],
"classviennacl_1_1ocl_1_1device.html#a22bb3e2ba98f0cd4c532b150f049aa19":[6,0,0,5,8,6],
"classviennacl_1_1ocl_1_1device.html#a258388f3587825635fe05b54796146ff":[6,0,0,5,8,34],
"classviennacl_1_1ocl_1_1device.html#a26a424782f982725453808a94763bd19":[6,0,0,5,8,30],
"classviennacl_1_1ocl_1_1device.html#a2aa011a6c0de926dc6af81e1ce7a19d7":[6,0,0,5,8,58],
"classviennacl_1_1ocl_1_1device.html#a2e429ddac81940fbea69c9c072b9e761":[6,0,0,5,8,25],
"classviennacl_1_1ocl_1_1device.html#a3078d11384e82353e6a91e0af0eb1a8d":[6,0,0,5,8,56],
"classviennacl_1_1ocl_1_1device.html#a308eaa94199f0329e3d8e7a47b4f06bd":[6,0,0,5,8,39],
"classviennacl_1_1ocl_1_1device.html#a30dea09ddfbe1947991ca9c05d4f78f4":[6,0,0,5,8,1],
"classviennacl_1_1ocl_1_1device.html#a3d1fe7f846ca6d057fa679710d6e298a":[6,0,0,5,8,64],
"classviennacl_1_1ocl_1_1device.html#a3e0686446372bb358a292f16d1fdce4f":[6,0,0,5,8,0],
"classviennacl_1_1ocl_1_1device.html#a43cbc02f3f425b8d5d3d1ddce3e3ff82":[6,0,0,5,8,65],
"classviennacl_1_1ocl_1_1device.html#a4e65fdb018cbae50f979c68d36c84d6b":[6,0,0,5,8,46],
"classviennacl_1_1ocl_1_1device.html#a5182025f56c76de6770e26b14165b00a":[6,0,0,5,8,9],
"classviennacl_1_1ocl_1_1device.html#a53aa2abb81ff8345c6cff2fcfbff88a0":[6,0,0,5,8,57],
"classviennacl_1_1ocl_1_1device.html#a5869fdbff4ae165ed1b0d13f332890ff":[6,0,0,5,8,44],
"classviennacl_1_1ocl_1_1device.html#a5e34e8981d66ae607893f6c518d1b8c2":[6,0,0,5,8,59],
"classviennacl_1_1ocl_1_1device.html#a629b4e093d4cdd7d14571e1be533c113":[6,0,0,5,8,62],
"classviennacl_1_1ocl_1_1device.html#a6a1ec04d6fc893299ace91a05857156a":[6,0,0,5,8,41],
"classviennacl_1_1ocl_1_1device.html#a6b77f537efe5f2a06d821b631603ce3e":[6,0,0,5,8,14],
"classviennacl_1_1ocl_1_1device.html#a6d696f181b320d07bfc4a28189127476":[6,0,0,5,8,23],
"classviennacl_1_1ocl_1_1device.html#a76beff9e3b77eb3aea2a7131c56a9427":[6,0,0,5,8,31],
"classviennacl_1_1ocl_1_1device.html#a7df7fa6e4d3190fdb344a698cf7c11d2":[6,0,0,5,8,45],
"classviennacl_1_1ocl_1_1device.html#a87caa1ab16a98e3a859e3b0733ac95da":[6,0,0,5,8,22],
"classviennacl_1_1ocl_1_1device.html#a88046764d096d2a3e7f3cbff0ae7fbdb":[6,0,0,5,8,63],
"classviennacl_1_1ocl_1_1device.html#a8e9ac6074e3cbdbb761b8ecb1c8796c8":[6,0,0,5,8,52],
"classviennacl_1_1ocl_1_1device.html#a960aab6eaa6c93ddee1a38b8ff4c3036":[6,0,0,5,8,37],
"classviennacl_1_1ocl_1_1device.html#a966136cb249ffe5e72bbff0f355d0063":[6,0,0,5,8,29],
"classviennacl_1_1ocl_1_1device.html#a9668779c429b2ac8da61686b3823cc34":[6,0,0,5,8,66],
"classviennacl_1_1ocl_1_1device.html#a97d9e24c5c361a615344d6cbb7811af4":[6,0,0,5,8,61],
"classviennacl_1_1ocl_1_1device.html#a9942f500eae3abcc9d4ed04571da7aec":[6,0,0,5,8,43],
"classviennacl_1_1ocl_1_1device.html#a9ad000d1e977e3fe36d7d0df7d11c94a":[6,0,0,5,8,19],
"classviennacl_1_1ocl_1_1device.html#a9cde93282f4e1fe0e5d29b2b47663ccd":[6,0,0,5,8,67],
"classviennacl_1_1ocl_1_1device.html#a9d70b7e5140a2276f041eb2f0da5e713":[6,0,0,5,8,12],
"classviennacl_1_1ocl_1_1device.html#a9efdfafd0819090844b28a123510283c":[6,0,0,5,8,20],
"classviennacl_1_1ocl_1_1device.html#a9fae6852832319bb6b63e536ed745302":[6,0,0,5,8,17],
"classviennacl_1_1ocl_1_1device.html#aa265513f3cd441860240d9d0a4da58c8":[6,0,0,5,8,32],
"classviennacl_1_1ocl_1_1device.html#aa9701e2af3c67fb0b9682be23d1e4549":[6,0,0,5,8,35],
"classviennacl_1_1ocl_1_1device.html#aacc7d3e11a3aaec763cd7d398e9b6638":[6,0,0,5,8,26],
"classviennacl_1_1ocl_1_1device.html#ab1542d4241b875ef9c073ceca3ac73a6":[6,0,0,5,8,4],
"classviennacl_1_1ocl_1_1device.html#ab2af60036bc98136d07090b9498e2b26":[6,0,0,5,8,42],
"classviennacl_1_1ocl_1_1device.html#ab911d6e8731391fb4d7b793445f95144":[6,0,0,5,8,47],
"classviennacl_1_1ocl_1_1device.html#abdd6815035bf4dfe6ff9b4bc1034f083":[6,0,0,5,8,8],
"classviennacl_1_1ocl_1_1device.html#ac21b85d536377b4823d57e247babc8ce":[6,0,0,5,8,54],
"classviennacl_1_1ocl_1_1device.html#ac512504fdb63e042e6034c145016d745":[6,0,0,5,8,33],
"classviennacl_1_1ocl_1_1device.html#acdd69338283c7a1ca06b11b0759c8843":[6,0,0,5,8,7],
"classviennacl_1_1ocl_1_1device.html#ad26c171dde7a764fa4f95c328b01bbab":[6,0,0,5,8,15],
"classviennacl_1_1ocl_1_1device.html#ad378cbbb6b0db7d460216537832f1ce5":[6,0,0,5,8,36],
"classviennacl_1_1ocl_1_1device.html#ad82b4da356f1f306b34eb87a53b8b7ec":[6,0,0,5,8,28],
"classviennacl_1_1ocl_1_1device.html#adc951e818db7dab22ebbf4c65e4cbe42":[6,0,0,5,8,24],
"classviennacl_1_1ocl_1_1device.html#add9bf288639d88f5188e09f71f7dd29c":[6,0,0,5,8,3],
"classviennacl_1_1ocl_1_1device.html#af7cd6b2e1cb1d9d8ce4b03593767508c":[6,0,0,5,8,38],
"classviennacl_1_1ocl_1_1device.html#af7dc4811d67aac349f79ed7fcbd4ecb1":[6,0,0,5,8,13],
"classviennacl_1_1ocl_1_1device.html#afd017572cf46fa80de40baf9eef1cb25":[6,0,0,5,8,10],
"classviennacl_1_1ocl_1_1device.html#afef78e460b0577fe72b8ad61a5aef8c5":[6,0,0,5,8,27],
"classviennacl_1_1ocl_1_1device.html#aff7d09f8a5665b125bf4b7c749c9c144":[6,0,0,5,8,16],
"classviennacl_1_1ocl_1_1device__not__available.html":[6,0,0,5,9],
"classviennacl_1_1ocl_1_1device__not__found.html":[6,0,0,5,10],
"classviennacl_1_1ocl_1_1double__precision__not__provided__error.html":[6,0,0,5,12],
"classviennacl_1_1ocl_1_1handle.html":[6,0,0,5,15],
"classviennacl_1_1ocl_1_1handle.html#a31e278200ed22f38e619ae63592c0e20":[6,0,0,5,15,1],
"classviennacl_1_1ocl_1_1handle.html#a3d32cab83155c46b4c944aec28431ec9":[6,0,0,5,15,11],
"classviennacl_1_1ocl_1_1handle.html#a5074caaee700015fc2d3b03540b01673":[6,0,0,5,15,7],
"classviennacl_1_1ocl_1_1handle.html#a5198f1189817af5da775a9a497c82959":[6,0,0,5,15,5],
"classviennacl_1_1ocl_1_1handle.html#a6c1f7f4d3445e6d6ef0e7106fa631417":[6,0,0,5,15,9],
"classviennacl_1_1ocl_1_1handle.html#a92f8d895f659fc44cbd6a594c88f2c3b":[6,0,0,5,15,12],
"classviennacl_1_1ocl_1_1handle.html#aabb9d0a4beed00a52500de6047651135":[6,0,0,5,15,4],
"classviennacl_1_1ocl_1_1handle.html#ab7d6c40f287c57376928b4114e8176ed":[6,0,0,5,15,13],
"classviennacl_1_1ocl_1_1handle.html#ab99e3ba37442fb195c1da4e022b6ff23":[6,0,0,5,15,10],
"classviennacl_1_1ocl_1_1handle.html#abd32b02babef2794751f39eb749a556a":[6,0,0,5,15,6],
"classviennacl_1_1ocl_1_1handle.html#ae3177c23936042f8984cc6f09f9e83d6":[6,0,0,5,15,3],
"classviennacl_1_1ocl_1_1handle.html#ae422ce46a3a48223c08b87cead97bf7e":[6,0,0,5,15,0],
"classviennacl_1_1ocl_1_1handle.html#ae9699f5b1f8d8df4eba7bacf0a563f32":[6,0,0,5,15,8]
};
